@@ -205,7 +205,7 @@ class work_sheet_tool():
         self.write_attr(source, target, pos_mapping)
 
     def write_list(self, pos: list, obj_value: dict) -> list:
-        tmp_row: list[Cell] = pos[-1]
+        tmp_row: list[Cell] = [copy.copy(col) for col in pos[-1]]
         col_list = []
         insert_pos = [len(pos)]
         while self.col_queue:
