@@ -44,11 +44,11 @@ class dynamic_method():
         start_row, end_row = p[0], p[-1]
         start = start_row
         align = Alignment(horizontal='center', vertical='center', wrap_text=True)
-        for i in range(start_row, end_row):
+        for i in range(start_row + 1, end_row):
             current_cell, prev_cell = pos[i][col], pos[i - 1][col]
             if isinstance(current_cell, Cell) and isinstance(prev_cell, Cell) and current_cell.value != prev_cell.value:
                 sheet.merge_cells(start_row=start, start_column=col + 1, end_column=col + 1, end_row=i - 1)
-                sheet[num_to_pos_char((col, start))].alignment = align
+                sheet[num_to_pos_char((col + 1, start))].alignment = align
                 start = i
         if end_row - start > 1:
             sheet[num_to_pos_char((col + 1, start))].alignment = align
